==> e107-2.1.1_1.txz: usr/local/www/e107/e107_plugins/chatbox_menu/languages/English/English.php <==
<?php
/*
 * e107 website system
 *
 * Copyright (C) 2008-2009 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 *
 *
 * $Source: /cvs_backup/e107_0.8/e107_plugins/chatbox_menu/languages/English/English.php,v $
 * $Revision$
 * $Date$
 * $Author$
 */

define("CHATBOX_L1", "Unable to accept post as that username is registered - if it is your username please login to post.");
// define("CHATBOX_L2", "Chatbox");
define("CHATBOX_L3", "You must be logged in to post comments on this site - please either log in or if you are not registered click <a href='".e_SIGNUP."'>here</a> to signup");
define("CHATBOX_L4", "Post new message");
define("CHATBOX_L5", "Reset");
define("CHATBOX_L6", "[blocked by admin]");
define("CHATBOX_L7", "Unblock");
define("CHATBOX_L8", "Info");
define("CHATBOX_L9", "Block");
// define("CHATBOX_L10", "Delete");
define("CHATBOX_L11", "No messages yet.");
define("CHATBOX_L12", "View all posts");
define("CHATBOX_L13", "moderate chatbox");
define("CHATBOX_L14", "Emotes");
define("CHATBOX_L15", "Post too long, or empty post submitted");
// define("CHATBOX_L16", "Anonymous");
define("CHATBOX_L17", "Duplicate post");
define("CHATBOX_L18", "Chatbox messages moderated");
define("CHATBOX_L19", "You may only post once every ".(FLOODPROTECT ? FLOODTIMEOUT : 'n/a')." seconds");

define("CHATBOX_L20", "Chatbox (all posts)");
// define("CHATBOX_L21", "Chat Posts");
define("CHATBOX_L22", "on");
// define("CHATBOX_L23", "Error!");
define("CHATBOX_L24", "You do not have the correct permissions to view this page.");
define("CHATBOX_L25", "[ this post has been blocked by admin ]");

define("LAN_CHATBOX_100", "Type your message here.");
?>

==> e107-2.1.2.txz: usr/local/www/e107/e107_plugins/chatbox_menu/languages/English/English.php <==
<?php
/*
 * e107 website system
 *
 * Copyright (C) 2008-2009 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 *
 *
 * $Source: /cvs_backup/e107_0.8/e107_plugins/chatbox_menu/languages/English/English.php,v $
 * $Revision$
 * $Date$
 * $Author$
 */

define("CHATBOX_L1", "Unable to accept post as that username is registered - if it is your username please login to post.");
// define("CHATBOX_L2", "Chatbox");
define("CHATBOX_L3", "You must be logged in to post comments on this site - please either log in from the Login box or from [here].");
define("CHATBOX_L3b", "If you are not registered click [here] to signup. ");
define("CHATBOX_L4", "Post new message");
define("CHATBOX_L5", "Reset");
define("CHATBOX_L6", "[blocked by admin]");
define("CHATBOX_L7", "Unblock");
define("CHATBOX_L8", "Info");
define("CHATBOX_L9", "Block");
// define("CHATBOX_L10", "Delete");
define("CHATBOX_L11", "No messages yet.");
define("CHATBOX_L12", "View all posts");
define("CHATBOX_L13", "moderate chatbox");
define("CHATBOX_L14", "Emotes");
define("CHATBOX_L15", "Post too long, or empty post submitted");
// define("CHATBOX_L16", "Anonymous");
define("CHATBOX_L17", "Duplicate post");
define("CHATBOX_L18", "Chatbox messages moderated");
define("CHATBOX_L19", "You may only post once every ".(FLOODPROTECT ? FLOODTIMEOUT : 'n/a')." seconds");

define("CHATBOX_L20", "Chatbox (all posts)");
// define("CHATBOX_L21", "Chat Posts");
define("CHATBOX_L22", "on");
// define("CHATBOX_L23", "Error!");
define("CHATBOX_L24", "You do not have the correct permissions to view this page.");
define("CHATBOX_L25", "[ this post has been blocked by admin ]");

define("LAN_CHATBOX_100", "Type your message here.");
?>
